@@ -9,16 +9,17 @@ use Giblog::API;
 use Carp 'confess';
 use Pod::Usage 'pod2usage';
 use List::Util 'min';
+use File::Spec;
 
-our $VERSION = '1.00';
+our $VERSION = '1.03_01';
 
 sub new {
   my $class = shift;
-  
+
   my $self = {
     @_
   };
-  
+
   return bless $self, $class;
 }
 
@@ -42,7 +43,7 @@ sub _unindent {
 
 sub run_command {
   my ($class, @argv) = @_;
-  
+
   # Command line option
   local @ARGV = @argv;
   my $getopt_option_save = Getopt::Long::Configure(qw(default no_auto_abbrev no_ignore_case));
@@ -51,20 +52,20 @@ sub run_command {
     "H|home=s" => \my $home_dir,
   );
   Getopt::Long::Configure($getopt_option_save);
-  
+
   # Command name
   my $command_name = shift @ARGV;
-  
+
   # Show help
   die _extract_usage if $help || !$command_name;
-  
+
   # Giblog
   my $giblog = Giblog->new(home_dir => $home_dir);
-  
+
   # API
   my $api = Giblog::API->new(giblog => $giblog);
-  
-  # Add "lib" in home directory to include path 
+
+  # Add "lib" in home directory to include path
   local @INC = @INC;
   if (defined $home_dir) {
     unshift @INC, "$home_dir/lib";
@@ -72,7 +73,7 @@ sub run_command {
   else {
     unshift @INC, "lib";
   }
-  
+
   # Command is implemented in command
   my $command_class = "Giblog::Command::$command_name";
   eval "use $command_class;";
@@ -80,7 +81,7 @@ sub run_command {
     confess "Can't load command $command_class:\n$!\n$@";
   }
   my $command = $command_class->new(api => $api);
-  
+
   @argv = @ARGV;
   $command->run(@argv);
 }
@@ -88,6 +89,66 @@ sub run_command {
 sub home_dir { shift->{'home_dir'} }
 sub config { shift->{config} }
 
+sub build {
+  my ($class) = @_;
+
+  # Build
+  my $cmd = 'giblog build';
+  system($cmd) == 0
+    or die "Can't execute $cmd: $!";
+}
+
+sub serve {
+  my ($class, $app) = @_;
+
+  # Read config file
+  my $config_file = "$FindBin::Bin/giblog.conf";
+  my $config;
+  $config = do $config_file
+    or die "Can't read config file $config_file";
+
+  # Remove base path before dispatch
+  my $base_path = $config->{base_path};
+  if (defined $base_path) {
+
+    # Subdir depth
+    my @parts = File::Spec->splitdir($base_path);
+    my $subdir_depth = @parts - 1;
+
+    $app->hook(before_dispatch => sub {
+      my $c = shift;
+
+      # Root is redirect
+      unless (@{$c->req->url->path->parts}) {
+        $c->stash(is_redirect => 1);
+      }
+
+      # Remove base path
+      for (my $i = 0; $i < $subdir_depth; $i++) {
+        shift @{$c->req->url->path->parts};
+      }
+    });
+  }
+
+  my $r = $app->routes;
+
+  $r->get('/' => sub {
+    my $c = shift;
+
+    my $is_redirect = $c->stash('is_redirect');
+    if ($is_redirect) {
+      $c->redirect_to($base_path);
+    }
+    else {
+      $c->reply->static('index.html');
+    }
+  });
+
+  $app->start;
+}
+
+=encoding utf8
+
 =head1 NAME
 
 Giblog - Web site and Blog builders you can manage with Git
@@ -123,7 +184,7 @@ All created files is B<static files>, so you can manage them using B<git>.
 You can B<customize your website by Perl>.
 
 =head1 SYNOPSYS
-  
+
   # New empty web site
   giblog new mysite
 
@@ -132,22 +193,22 @@ You can B<customize your website by Perl>.
 
   # New blog
   giblog new_blog mysite
-  
+
   # Change directory
   cd mysite
-  
+
   # Add new entry
   giblog add
 
   # Build web site
   giblog build
-  
-  # Check web site in local environment(need Mojolicious)
-  morbo serve.pl
+
+  # Serve a web site
+  giblog serve
 
   # Add new entry with home directory
   giblog add --home /home/kimoto/mysite
-  
+
   # Build web site with home directory
   giblog build --home /home/kimoto/mysite
 
@@ -185,6 +246,8 @@ Giblog have the following features.
 
 =item * Fast. Build 645 pages by 0.78 seconds in starndard linux environment.
 
+=item * Support Github Pages, both user and project page.
+
 =back
 
 =head1 TUTORIAL
@@ -231,7 +294,7 @@ You need to change directory to "mysite" before run "add" command if you are in
   cd mysite
 
 "add" command add entry page.
-  
+
   giblog add
 
 Created file name is, for example,
@@ -287,7 +350,7 @@ Files in "templates/static" directory is only copied to public files by build pr
 =head2 Customize header or footer, side bar, top of content, bottom of content
 
 You can customize header, footer, side bar, top of content, bottom of content.
-  
+
   ------------------------
   Header
   ------------------------
@@ -319,7 +382,7 @@ You can customize HTML header.
       <!-- HTML header -->
     </head>
     <body>
-    
+
     </body>
   </html>
 
@@ -355,23 +418,23 @@ build process is writen in "lib/Giblog/Command/build.pm".
 
   sub run {
     my ($self, @args) = @_;
-    
+
     # API
     my $api = $self->api;
-    
+
     # Read config
     my $config = $api->read_config;
-    
+
     # Copy static files to public
     $api->copy_static_files_to_public;
 
     # Get files in templates directory
     my $files = $api->get_templates_files;
-    
+
     for my $file (@$files) {
       # Data
       my $data = {file => $file};
-      
+
       # Get content from file in templates directory
       $api->get_content($data);
 
@@ -398,7 +461,7 @@ build process is writen in "lib/Giblog/Command/build.pm".
 
       # Read common templates
       $api->read_common_templates($data);
-      
+
       # Add meta title
       $api->add_meta_title($data);
 
@@ -407,17 +470,17 @@ build process is writen in "lib/Giblog/Command/build.pm".
 
       # Build entry html
       $api->build_entry($data);
-      
+
       # Build whole html
       $api->build_html($data);
-      
+
       # Write to public file
       $api->write_to_public_file($data);
     }
-    
+
     # Create index page
     $self->create_index;
-    
+
     # Create list page
     $self->create_list;
   }
@@ -428,16 +491,85 @@ If you need to know Giblog API, see L<Giblog::API>.
 
 =head2 Serve web site
 
-If you have L<Mojolicious>, you can serve web site in local environment.
+You can serve web site by C<serve> command.
 
-   morbo serve.pl
+   # Serve web site
+   giblog serve
 
 You see the following message.
 
-   Server available at http://127.0.0.1:3000
-   Server start
+   Web application available at http://127.0.0.1:3000
 
-If files in "templates" directory is changed, Web site is automatically rebuild.
+This command is same as the following code. L<morbo> command of L<Mojolicious> start up C<serve.pl>.
+
+   # Same as the following
+   morbo -w giblog.conf -w lib -w templates serve.pl
+
+If C<giblog.conf>, files in C<templates> or C<lib> directory is changed, Web site is automatically rebuild.
+
+If you use before Giblog 2.0, you can serve a web site by the following way.
+
+   # Old style before Giblog 2.0
+   morbo serve.pl
+
+=head2 Publish web site
+
+You can publish the web site by C<publish> command.
+
+   # Publish the web site
+   giblog publish origin main
+
+This command is same as the following.
+
+  git -C public add .
+  git -C public commit -m "Published at YY-mm-dd HH:MM:SS"
+  git -C public push origin main
+
+=head1 CONFIG FILE
+
+Giblog config file is "giblog.conf".
+
+This is Perl script and return config as hash reference.
+
+  use strict;
+  use warnings;
+  use utf8;
+
+  # giblog.conf
+  {
+    site_title => 'mysite😄',
+    site_url => 'http://somesite.example',
+  }
+
+=head2 site_title
+
+  site_title => 'mysite😄'
+
+Site title
+
+=head2 site_url
+
+  site_url => 'http://somesite.example'
+
+Site URL.
+
+=head2 base_path
+
+  base_path => '/subdir'
+
+Base path. Base path is used to deploy your site to sub directory.
+
+For example, Project page URL of Github Pages is
+
+  https://yuki-kimoto.github.io/giblog-theme1-public/
+
+You specify the following
+
+  base_path => '/giblog-theme1-public'
+
+Top character of base_path must be slash "/".
+
+HTML files is output into "public/giblog-theme1-public" directory.
 
 =head1 METHODS
 
@@ -479,10 +611,22 @@ Get Giblog config.
 
 Get home directory.
 
+=head1 FAQ
+
+=head2 Dose Giblog support Windows?
+
+Giblog does'nt support Native Windows(Strawberry Perl, or Active Perl) because Giblog depends on Git and Mojolicious.
+
+If you use Giblog in Windows, you can use WSL2.
+
 =head1 AUTHOR
 
 Yuki Kimoto, C<< <kimoto.yuki at gmail.com> >>
 
+=head1 CONTRIBUTORS
+
+Yasuaki Omokawa, C<< <omokawa at senk-inc.co.jp> >>
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2018-2019 Yuki Kimoto.
